==> ontoTools_1.1.0.tar.gz: ontoTools/R/otkv.R <==
otkvEnv2namedSparse <- function(obs, tms, otkvEnv) {
#
# object-term key-value environment converted to
# named sparse matrix
# 
# very slow for large matrices!
#
require(SparseM)
# object term key-value list
# args seem excessive but need to account for a list that doesn't map to all terms
lnames <- ls(env=otkvEnv)
if (!(all(lnames %in% obs))) stop("some kvlist names not in obs vec")
rowind <- mapNamesInds(obs)
colind <- mapNamesInds(tms)
rf <- function(x) get(x,env=rowind[["n2i"]])
cf <- function(x) unlist(multiget(x,env=colind[["n2i"]]))
mat <- makeSparseZero(length(obs), length(tms))# as.matrix.csr(0.0,nrow=length(obs),ncol=length(tms))
for (i in 1:length(lnames))
 {
 if (i %% 100 == 0) cat(i)
 curob <- lnames[i]
 rind <- rf(curob)
 targc <- cf(get(curob,env=otkvEnv))
 for (j in 1:length(targc))
    {
    cind <- targc[j]
    if (is.na(cind) | is.na(rind)) next
    mat[ rind, cind ] <- 1.0
    }
 }
new( "namedSparse", mat=mat, Dimnames=list(obs,tms), rowindex=rowind, 
 colindex=colind)
}

otkvList2namedSparse <- function(obs, tms, otkvlist) {
require(SparseM)
# object term key-value list
# args seem excessive but need to account for a list that doesn't map to all terms
lnames <- names(otkvlist)
if (!(all(lnames %in% obs))) stop("some kvlist names not in obs vec")
rowind <- mapNamesInds(obs)
colind <- mapNamesInds(tms)
rf <- function(x) get(x,env=rowind[["n2i"]])
cf <- function(x) unlist(multiget(x,env=colind[["n2i"]]))
mat <- makeSparseZero(length(obs), length(tms))# as.matrix.csr(0.0,nrow=length(obs),ncol=length(tms))
for (i in 1:length(otkvlist))
 {
 if (i %% 100 == 0) cat(i)
 curob <- lnames[i]
 rind <- rf(curob)
 targc <- cf(otkvlist[[curob]])
 for (j in 1:length(targc))
    {
    cind <- targc[j]
    if (is.na(cind) | is.na(rind)) next
    mat[ rind, cind ] <- 1.0
    }
 }
new( "namedSparse", mat=mat, Dimnames=list(obs,tms), rowindex=rowind, 
 colindex=colind)
}

==> ontoTools_1.8.0.tar.gz: ontoTools/R/otkv.R <==
otkvEnv2namedSparse <- function(obs, tms, otkvEnv) {
#
# object-term key-value environment converted to
# named sparse matrix
#
# very slow for large matrices!
#
require(SparseM)
# object term key-value list
# args seem excessive but need to account for a list that doesn't map to all terms
lnames <- ls(env=otkvEnv)
if (!(all(lnames %in% obs))) stop("some kvlist names not in obs vec")
mat <- makeSparseZero(length(obs), length(tms))# as.matrix.csr(0.0,nrow=length(obs),ncol=length(tms))
for (i in 1:length(lnames))
 {
 if (i %% 100 == 0) cat(i)
 curob <- lnames[i]
 rind <- match(curob,obs)
 cind <- match(otkvEnv[[curob]], tms)

 if (any(is.na(cind)) | is.na(rind)) next
 mat[ rind, cind ] <- 1.0
# for (j in 1:length(targc))
#    {
#    cind <- targc[j]
#    if (is.na(cind) | is.na(rind)) next
#    mat[ rind, cind ] <- 1.0
#    }
 }
new( "namedSparse", mat=mat, Dimnames=list(obs,tms))
}

otkvList2namedSparse <- function(obs, tms, otkvlist) {
require(SparseM)
# object term key-value list
# args seem excessive but need to account for a list that doesn't map to all terms
lnames <- names(otkvlist)
if (!(all(lnames %in% obs))) stop("some kvlist names not in obs vec")
mat <- makeSparseZero(length(obs), length(tms))# as.matrix.csr(0.0,nrow=length(obs),ncol=length(tms))
for (i in 1:length(otkvlist))
 {
 if (i %% 100 == 0) cat(i)
 curob <- lnames[i]
 rind <- match(curob,obs)
 targc <- match( otkvlist[[curob]], tms )
 for (j in 1:length(targc))
    {
    cind <- targc[j]
    if (is.na(cind) | is.na(rind)) next
    mat[ rind, cind ] <- 1.0
    }
 }
new( "namedSparse", mat=mat, Dimnames=list(obs,tms))
}
